==> ICA-1.5.tar.gz: ICA-1.5/src/MSI/Spec2Gen/signal.c <==
/*
   Owner:       Copyright 1992 The Ohio State University,
                Integrated Chameleon Architecture
   Module:      $RCSfile: signal.c,v $
   Purpose:     

   Programmer:  Conleth O'Connell
   Reviewer:    
   Revision:    $Revision: 1.3 $
   Date:        $Date: 92/05/20 11:50:43 $

   HISTORY
   $Log:	signal.c,v $
 * Revision 1.3  92/05/20  11:50:43  ware
 * signal() had an extra parameter
 * 
 * Revision 1.2  92/03/16  13:03:40  ware
 * Conditionalize the title
 * 
 * Revision 1.1  1992/01/14  20:53:11  cso
 * Initial revision
 *

   Functions Index:
   AVAIL   NAME DEPENDS ON INTERNALLY      EXTERNALLY
   -----   ----            ----------      ----------

*/

/* #INCLUDES */

#include <signal.h>
#include "widgets.h"

/* #DEFINES  */

/*  EXTERNS  */

#include "main.h"
#include "save.h"
#include "status.h"

/*  GLOBALS  */



/*
   FUNCTION: 		FileDump

   Synopsis: 
       Dump the present grammar into a file and inform the user.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE     WHO      REASON

   System files modified:
       Taking advantage of write access to /tmp.  In general this may not
       work.

   Globals used:
       Root     To access the top of the tree and generate the grammar

   Globals Modified:
       none

   Return value:	void

   Range:		none
*/

static void
FileDump()

{
   FILE
      *fptr; /* File pointer to dump the present grammar */

   /*
    * Attempt to open a file,
    * If not allowed to do so, inform the user
    * Else generate a devegram file and inform the user where it is
    */
   fptr = fopen("/tmp/dump.s2g", "w");
   if (fptr == NULL)
   {
      fprintf(stderr, "Unable to open /tmp/dump.s2g\n");
      fprintf(stderr, "Failing without recourse\n");
   }
   else
   {
      SaveFile(fptr);
      fclose(fptr);
      fprintf(stderr, "The specification can be found in /tmp/dump.s2g\n");
   }
   return;
}




/*
   FUNCTION: 		HandleSignal

   Synopsis: 
       To provide a graceful means of dying by at least saving out 
       any changes to a grammar.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE       WHO    REASON
       91/03/08   cso    Dump the grammar even if I don't recognize
                          the signal.
       91/05/23   cso    Dump the grammar for Bus errors.
       91/10/14   cso    Added Illegal instruction signal to handle

   Globals used:
       none

   Globals Modified:
       none

   Return value:	static void

   Range:		none
*/

static void
HandleSignal(sig)

int
   sig;           /* The signal needing handling */

{
   /*
    * Depending on the signal, handle it
    */
   switch (sig)
   {
   default:
      /*
       * This signal is not handled
       */
      fprintf(stderr, "Didn't match anybody\n");
      FileDump();
      break;

   case SIGBUS:
      /*
       * This is a bus error, dump the grammar
       */
      fprintf(stderr, "Received a Bus error signal\n");
      FileDump();
      break;

   case SIGHUP:
      /*
       * This signal is not handled
       */
      fprintf(stderr, "Received a HangUp signal\n");
      break;

   case SIGILL:
      /*
       * This is an illegal instruction, dump the grammar
       */
      fprintf(stderr, "Received an Illegal Instruction signal\n");
      FileDump();
      break;

   case SIGINT:
      /*
       * This signal is not handled
       */
      fprintf(stderr, "Received a Ctrl-C signal\n");
      break;

   case SIGSEGV:
      /*
       * This is a segmentation violation, dump the grammar
       */
      fprintf(stderr, "Received a Segmentation Violation signal\n");
      FileDump();
      break;
   }
   exit(2);
}



/*
   FUNCTION: 		InstallSignalHandlers

   Synopsis: 
       Install the signal handler for certain types of signals.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE       WHO    REASON
       91/10/14   cso    Added Illegal instruction signal to handle

   Globals used:
       none

   Globals Modified:
       none

   Return value:	void

   Range:		none
*/

void
InstallSignalHandlers()

{
   /*
    * As the installation occurs, check for an error, inform the user
    * if installation of any of the signals have failed
    */
   if ((signal(SIGBUS,  HandleSignal) == SIG_ERR) ||
       (signal(SIGHUP,  HandleSignal) == SIG_ERR) ||
       (signal(SIGILL,  HandleSignal) == SIG_ERR) ||
       (signal(SIGINT,  HandleSignal) == SIG_ERR) ||
       (signal(SIGSEGV, HandleSignal) == SIG_ERR))
   {
      XicaStatus(Statw, "Not all signal() handlers were installed\n");
   }
   return;
}

==> ICA-1.6.tar.gz: ICA-1.6/src/MSI/Spec2Gen/signal.c <==
/*
   Owner:       Copyright 1992 The Ohio State University,
                Integrated Chameleon Architecture
   Module:      signal.c,v
   Purpose:     

   Programmer:  Conleth O'Connell
   Reviewer:    
   Revision:    1.4
   Date:        1993/04/19 17:09:24

   HISTORY
   signal.c,v
 * Revision 1.4  1993/04/19  17:09:24  ware
 * Merged John Boyds changes.
 *
 * Revision 1.3  92/05/20  11:50:43  ware
 * signal() had an extra parameter
 * 
 * Revision 1.2  92/03/16  13:03:40  ware
 * Conditionalize the title
 * 
 * Revision 1.1  1992/01/14  20:53:11  cso
 * Initial revision
 *

   Functions Index:
   AVAIL   NAME DEPENDS ON INTERNALLY      EXTERNALLY
   -----   ----            ----------      ----------

*/

/* #INCLUDES */

#include <signal.h>
#include "widgets.h"

/* #DEFINES  */

/*  EXTERNS  */

#include "main.h"
#include "save.h"
#include "status.h"

/*  GLOBALS  */



/*
   FUNCTION: 		FileDump

   Synopsis: 
       Dump the present grammar into a file and inform the user.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE     WHO      REASON

   System files modified:
       Taking advantage of write access to /tmp.  In general this may not
       work.

   Globals used:
       Root     To access the top of the tree and generate the grammar

   Globals Modified:
       none

   Return value:	void

   Range:		none
*/

static void
FileDump()

{
   FILE
      *fptr; /* File pointer to dump the present grammar */

   /*
    * Attempt to open a file,
    * If not allowed to do so, inform the user
    * Else generate a devegram file and inform the user where it is
    */
   fptr = fopen("/tmp/dump.s2g", "w");
   if (fptr == NULL)
   {
      fprintf(stderr, "Unable to open /tmp/dump.s2g\n");
      fprintf(stderr, "Failing without recourse\n");
   }
   else
   {
      SaveFile(fptr);
      fclose(fptr);
      fprintf(stderr, "The specification can be found in /tmp/dump.s2g\n");
   }
   return;
}




/*
   FUNCTION: 		HandleSignal

   Synopsis: 
       To provide a graceful means of dying by at least saving out 
       any changes to a grammar.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE       WHO    REASON
       91/03/08   cso    Dump the grammar even if I don't recognize
                          the signal.
       91/05/23   cso    Dump the grammar for Bus errors.
       91/10/14   cso    Added Illegal instruction signal to handle

   Globals used:
       none

   Globals Modified:
       none

   Return value:	static void

   Range:		none
*/

static void
HandleSignal(sig)

int
   sig;           /* The signal needing handling */

{
   /*
    * Depending on the signal, handle it
    */
   switch (sig)
   {
   default:
      /*
       * This signal is not handled
       */
      fprintf(stderr, "Didn't match anybody\n");
      FileDump();
      break;

#ifndef linux
   case SIGBUS:
      /*
       * This is a bus error, dump the grammar
       */
      fprintf(stderr, "Received a Bus error signal\n");
      FileDump();
      break;
#endif

   case SIGHUP:
      /*
       * This signal is not handled
       */
      fprintf(stderr, "Received a HangUp signal\n");
      break;

   case SIGILL:
      /*
       * This is an illegal instruction, dump the grammar
       */
      fprintf(stderr, "Received an Illegal Instruction signal\n");
      FileDump();
      break;

   case SIGINT:
      /*
       * This signal is not handled
       */
      fprintf(stderr, "Received a Ctrl-C signal\n");
      break;

   case SIGSEGV:
      /*
       * This is a segmentation violation, dump the grammar
       */
      fprintf(stderr, "Received a Segmentation Violation signal\n");
      FileDump();
      break;
   }
   exit(2);
}



/*
   FUNCTION: 		InstallSignalHandlers

   Synopsis: 
       Install the signal handler for certain types of signals.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE       WHO    REASON
       91/10/14   cso    Added Illegal instruction signal to handle

   Globals used:
       none

   Globals Modified:
       none

   Return value:	void

   Range:		none
*/

void
InstallSignalHandlers()

{
   /*
    * As the installation occurs, check for an error, inform the user
    * if installation of any of the signals have failed
    */
   if (
#ifndef linux
       (signal(SIGBUS,  HandleSignal) == SIG_ERR) ||
#endif
       (signal(SIGHUP,  HandleSignal) == SIG_ERR) ||
       (signal(SIGILL,  HandleSignal) == SIG_ERR) ||
       (signal(SIGINT,  HandleSignal) == SIG_ERR) ||
       (signal(SIGSEGV, HandleSignal) == SIG_ERR))
   {
      XicaStatus(Statw, "Not all signal() handlers were installed\n");
   }
   return;
}
